Function inspect_ebml_for_reference

fn inspect_ebml_for_reference(
    next_stop: &str,
    section_title: &str,
) -> (u8, String)
Inspect an external Process file to understand a specific Section Reference

This function returns a numeric code based on what it finds:

  • 0 if section exists and is not a reference,
  • 1 if section exists and is a reference,
  • 2 if section doesn’t exist in the file
  • 3 if the file doesn’t exist or can’t be found

It also returns a String indicating what process to look into to find the referenced section. This is only necessary because the “daisy chaining” of references is in fact allowed. So for code “1” the returned String will be the next place to look for the source material.