Function parse_resource_line

fn parse_resource_line(line: &str) -> Resource
Pass the first part as the descriptive string for the resource The second part is a flag to determine if this resource needs to be calibrated to be used in this process