pub struct Resource {
name: String,
calibration: bool,
}Expand description
Resoures are named things that are needed to perform a Step - without them the Step can’t be performed
Fields
name: StringDescriptive name of the resource, with enough information to be unambiguous to the operator. For instance, if a specific screwdriver is needed, then “Screwdriver” is probably insufficient as the name of this resource.
calibration: boolDoes this resource need to be calibrated to be used in this process?
Implementations