Struct Section

pub struct Section {
    title: String,
    all_steps: Vec<Step>,
    relative_path: String,
}
Each Section struct contains all Steps within that document section

Fields

title: String

What the section is named, hopefully descriptive enough that operators know what to expect, and can anticipate operations

all_steps: Vec<Step>

Ordered set of all Steps in the section (each Step is rich with Sub-Step information as well)

relative_path: String

Relative path from the Process folder to the Process folder where the Section’s source exists, empty string unless SECREF is fetched

Implementations

Source

impl Section

Section needs “get” and “set/add” functions as well, to read and write private fields

fn new() -> Section

Blank string for the title, and empty Vec initialized for the list of Steps

pub fn get_title(&self) -> &String

Return reference to Section Title as string

pub fn get_all_steps(&self) -> &Vec<Step>

Return reference to Vector of Step structs

pub fn get_relative_path(&self) -> &String

Return the relative path from the Process folder to the Section’s Process folder, only non-empty for SECREF feature

fn set_title(&mut self, title: &str)

Change the Section Title

fn add_step(&mut self, step: Step)

Add a complete Step struct to the Vector of Step structs

fn set_relative_path(&mut self, path: &str)

Change the Relative Path from the Process folder to the Section’s Process folder, especially if performing a SECREF fetch