Function script_file_from_process

pub fn script_file_from_process(p: Process, lang: Language, wait: bool)
Create a script file using the Process struct, interpreted in a specified Language.

  • Some pre-canned comment blocks and stdout messages appear first
  • “Context” EBML lines appear as comments in the script
  • “Command” EBML lines appear as their own lines, verbatim
  • All other EBML is ignored

The script file appears alongside the process itself in its Process Folder.