pub(crate) fn print_filename_audit_to_stdout(v: &bool)Expand description
Look into each process folder, read the EBML, find the Number and Title, check consistency, print findings to stdout
The fundamental assumption is that stanhope will find any given EBML file in this location:
./
That is,
- a process’s folder is named “
- ” - the EBML file is named “
- .ebml”
This function attempts to traverse the library, checking these assumptions as it goes, and printing to stdout
Verbose version lists all diagnostic information about every process, not just the issues it finds