pub(crate) fn print_graphics_audit_to_stdout(v: &bool)Expand description
Look into each process folder, read the EBML, find the images, and check to see if they exist, print findings to stdout
This function finds all images that the EBML will use in its HTML output when processed:
- “Image” lines in the EBML
- “Image” lines in followed “Section Reference” links to other processes
- “Subject Image” line
- “Product Image” line
Verbose version lists all images, not just the missing ones