pub(crate) fn print_marking_audit_to_stdout(v: &bool)Expand description
Look into each process folder, read the EBML as well as the HTML!
The function tries to understand how a process is portion-marked, and report results
Verbose version lists all diagnostic information about every process, not just the issues it finds