pub struct Section {
title: String,
all_steps: Vec<Step>,
relative_path: String,
}Expand description
Each Section struct contains all Steps within that document section
Fields
title: StringWhat the section is named, hopefully descriptive enough that operators know what to expect, and can anticipate operations
all_steps: Vec<Step>Ordered set of all Steps in the section (each Step is rich with Sub-Step information as well)
relative_path: StringRelative path from the Process folder to the Process folder where the Section’s source exists, empty string unless SECREF is fetched
Implementations
Sourceimpl Section
Section needs “get” and “set/add” functions as well, to read and write private fields
impl Section
Section needs “get” and “set/add” functions as well, to read and write private fields
Sourcefn new() -> Section
fn new() -> Section
Blank string for the title, and empty Vec initialized for the list of Steps
Sourcepub fn get_all_steps(&self) -> &Vec<Step>
pub fn get_all_steps(&self) -> &Vec<Step>
Return reference to Vector of Step structs
Sourcepub fn get_relative_path(&self) -> &String
pub fn get_relative_path(&self) -> &String
Return the relative path from the Process folder to the Section’s Process folder, only non-empty for SECREF feature
Sourcefn set_relative_path(&mut self, path: &str)
fn set_relative_path(&mut self, path: &str)
Change the Relative Path from the Process folder to the Section’s Process folder, especially if performing a SECREF fetch