pub struct Language {
name: String,
first: String,
c_open: String,
c_close: String,
last: String,
ext: String,
wait: String,
p_open: String,
p_close: String,
}Expand description
Scriptification requires a set of information describing the basic components of a scripting language. Each field of the Language struct includes sytax information.
Fields
name: StringHuman-readable name of the scripting language
first: StringFirst line of a script file in this language (e.g. shebang statement)
c_open: StringSingle-line comments start with this string. “c_open” means “single-line Comment OPENing”
c_close: StringSingle-line comments end with this string. Most comments only need an “open” but for completeness a “single-line Comment CLOSE” is defined
last: StringLast line of a script file in this language (e.g. exit or return statement)
ext: StringFile extension for scripts in this language, including the period (e.g. “.sh”)
wait: StringSyntactically correct way to wait for the user to press the ENTER key (functionality might vary by language limitations)
p_open: StringPrinting information out to stdout starts with this text (e.g. “echo “)
p_close: StringPrinting information out to stdout ends with this text